"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createCodePlugin = void 0;

var _react = _interopRequireDefault(require("react"));

var _core = require("@braindrop-editor/core");

var _slate = require("slate");

var _isHotkey = _interopRequireDefault(require("is-hotkey"));

var _slateReact = require("slate-react");

var _createDecorator = require("./createDecorator");

var _ElementCode = require("./ElementCode");

var _LeafCode = require("./LeafCode");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const createCodePlugin = (options = {}) => editor => {
  const defaultLanguage = options.defaultLanguage || 'javascript';
  const blockType = options.block && options.block.type || 'code';
  const BlockComponent = options.block && options.block.component || _ElementCode.ElementCode;

  function setBlockLanguage(element, language) {
    const path = _slateReact.ReactEditor.findPath(editor, element);

    _core.Transforms.setNodes(editor, {
      language
    }, {
      at: path
    });
  }

  return {
    onKeyDown: event => {
      if ((0, _isHotkey.default)('Tab', event)) {
        const parent = (0, _core.getBlockAbove)(editor);

        if (_slate.Element.isElement(parent[0]) && parent[0].type === 'code') {
          event.preventDefault();
          editor.insertText('  ');
        }
      }
    },
    decorate: (0, _createDecorator.createDecorator)(editor, blockType),
    renderLeaf: ({
      attributes,
      children,
      leaf
    }) => {
      const codeLeaf = leaf;

      if (codeLeaf.decorateCode) {
        return _react.default.createElement("span", _extends({}, attributes, {
          className: `token ${codeLeaf.token}`
        }), children);
      }

      return children;
    },
    elements: [{
      type: blockType,
      shortcuts: ['``` '],
      returnBehaviour: 'soft-break',
      turnInto: (editor, element, turnIntoOptions) => {
        _core.Transforms.setNodes(editor, {
          type: blockType,
          language: defaultLanguage
        }, turnIntoOptions);
      },
      insert: (editor, insertOptions) => {
        _core.Transforms.insertNodes(editor, {
          type: blockType,
          properties: {
            language: defaultLanguage
          },
          children: [{
            text: ''
          }]
        }, insertOptions);
      },
      ...(options.block || {}),
      component: props => _react.default.createElement(BlockComponent, _extends({}, props, {
        onSetLanguage: setBlockLanguage
      }))
    }],
    leaves: [{
      mark: 'code',
      component: _LeafCode.LeafCode,
      shortcuts: [{
        start: '`',
        end: '`'
      }]
    }]
  };
};

exports.createCodePlugin = createCodePlugin;
//# sourceMappingURL=CodePlugin.js.map